from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportSubcatchments(PrimaryBase):
    __tablename__ = 'spark_report_subcatchments'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    order = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    datetime = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    date = Column(DATE, autoincrement=False)
    time = Column(TIME, autoincrement=False)
    is_forecasted = Column(BOOLEAN, primary_key=True, autoincrement=False)
    rainfall = Column(NUMERIC, autoincrement=False)
    snow = Column(NUMERIC, autoincrement=False)
    evap = Column(NUMERIC, autoincrement=False)
    infil = Column(NUMERIC, autoincrement=False)
    runoff = Column(NUMERIC, autoincrement=False)
    gw_flow = Column(NUMERIC, autoincrement=False)
    gw_elev = Column(NUMERIC, autoincrement=False)
    soil_moist = Column(NUMERIC, autoincrement=False)
    washoff = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpSubcatchment(PrimaryBase):
    __tablename__ = 'inp_subcatchment'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    name = Column(VARCHAR(250), autoincrement=False)
    raingage = Column(VARCHAR(50), autoincrement=False)
    outlet = Column(VARCHAR(50), autoincrement=False)
    total_area = Column(DOUBLE_PRECISION, autoincrement=False)
    pcnt_imperv = Column(DOUBLE_PRECISION, autoincrement=False)
    width = Column(DOUBLE_PRECISION, autoincrement=False)
    pcnt_slope = Column(DOUBLE_PRECISION, autoincrement=False)
    curb_length = Column(DOUBLE_PRECISION, autoincrement=False)
    snow_pack = Column(VARCHAR(50), autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
    mukey = Column(VARCHAR(191), autoincrement=False)
    site_id = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, SMALLINT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpLidControlSubvalues(PrimaryBase):
    __tablename__ = 'inp_lid_control_subvalues'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    inp_lid_control_value_id = Column(BIGINT, nullable=False, autoincrement=False)
    parameter_number = Column(SMALLINT, nullable=False, autoincrement=False)
    value = Column(VARCHAR(50), nullable=False, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class UsStates(PrimaryBase):
    __tablename__ = 'us_states'
    __table_args__ = {'schema': 'public'}
    
    column_not_exist_in_db = Column(INTEGER, primary_key=True) # Needed to circumvent primary key requirement in sqlalchemy
    region = Column(INTEGER, autoincrement=False)
    division = Column(INTEGER, autoincrement=False)
    state_id = Column(INTEGER, autoincrement=False)
    statens = Column(INTEGER, autoincrement=False)
    stusps = Column(VARCHAR(10), autoincrement=False)
    name = Column(VARCHAR(255), autoincrement=False)
    lsad = Column(INTEGER, autoincrement=False)
    mtfcc = Column(VARCHAR(255), autoincrement=False)
    funcstat = Column(VARCHAR(255), autoincrement=False)
    aland = Column(BIGINT, autoincrement=False)
    awater = Column(BIGINT, autoincrement=False)
    intptlat = Column(VARCHAR(255), autoincrement=False)
    intptlon = Column(VARCHAR(255), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpSnowpackValues(PrimaryBase):
    __tablename__ = 'inp_snowpack_values'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    inp_snowpack_id = Column(BIGINT, nullable=False, autoincrement=False)
    surface = Column(VARCHAR(30), nullable=False, autoincrement=False)
    parameter1 = Column(DOUBLE_PRECISION, autoincrement=False)
    parameter2 = Column(DOUBLE_PRECISION, autoincrement=False)
    parameter3 = Column(DOUBLE_PRECISION, autoincrement=False)
    parameter4 = Column(DOUBLE_PRECISION, autoincrement=False)
    parameter5 = Column(DOUBLE_PRECISION, autoincrement=False)
    parameter6 = Column(DOUBLE_PRECISION, autoincrement=False)
    parameter7 = Column(DOUBLE_PRECISION, autoincrement=False)
    subcatchment = Column(VARCHAR(50), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class EventAnalysisResults(PrimaryBase):
    __tablename__ = 'event_analysis_results'
    __table_args__ = {'schema': 'predictions'}
    
    column_not_exist_in_db = Column(INTEGER, primary_key=True) # Needed to circumvent primary key requirement in sqlalchemy
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    site_id = Column(TEXT, nullable=False, autoincrement=False)
    dwf_simulation_id = Column(INTEGER, autoincrement=False)
    wwf_simulation_id = Column(INTEGER, autoincrement=False)
    event_id = Column(INTEGER, autoincrement=False)
    sewershed_id = Column(TEXT, autoincrement=False)
    groundwater_infiltration = Column(NUMERIC, autoincrement=False)
    gwi_per_idm = Column(NUMERIC, autoincrement=False)
    dry_weather_flow_ratio = Column(NUMERIC, autoincrement=False)
    ave_dry_weather_flow = Column(NUMERIC, autoincrement=False)
    total_i_i = Column(NUMERIC, autoincrement=False)
    r_value = Column(NUMERIC, autoincrement=False)
    i_i_per_idm = Column(NUMERIC, autoincrement=False)
    peak_flow = Column(NUMERIC, autoincrement=False)
    peaking_factor = Column(NUMERIC, autoincrement=False)
    peak_i_i = Column(NUMERIC, autoincrement=False)
    idm = Column(NUMERIC, autoincrement=False)
    peak_dwf = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkRptSubcatchmentRunoffSummaries(PrimaryBase):
    __tablename__ = 'spark_rpt_subcatchment_runoff_summaries'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    order = Column(INTEGER, primary_key=True, autoincrement=False)
    subcatchment = Column(TEXT, primary_key=True, autoincrement=False)
    total_precip_in = Column(NUMERIC, autoincrement=False)
    total_runon_in = Column(NUMERIC, autoincrement=False)
    total_evap_in = Column(NUMERIC, autoincrement=False)
    total_infil_in = Column(NUMERIC, autoincrement=False)
    imperv_runoff_in = Column(NUMERIC, autoincrement=False)
    perv_runoff_in = Column(NUMERIC, autoincrement=False)
    total_runoff_in = Column(NUMERIC, autoincrement=False)
    total_runoff_gallons = Column(NUMERIC, autoincrement=False)
    peak_runoff_cfs = Column(NUMERIC, autoincrement=False)
    runoff_coeff = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Layer(PrimaryBase):
    __tablename__ = 'layer'
    __table_args__ = {'schema': 'topology'}
    
    topology_id = Column(INTEGER, primary_key=True, autoincrement=False)
    layer_id = Column(INTEGER, primary_key=True, autoincrement=False)
    schema_name = Column(VARCHAR, nullable=False, autoincrement=False)
    table_name = Column(VARCHAR, nullable=False, autoincrement=False)
    feature_column = Column(VARCHAR, nullable=False, autoincrement=False)
    feature_type = Column(INTEGER, nullable=False, autoincrement=False)
    level = Column(INTEGER, nullable=False, autoincrement=False)
    child_id = Column(INTEGER, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class LofModels(PrimaryBase):
    __tablename__ = 'lof_models'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    s3_model_uri = Column(VARCHAR(191), nullable=False, autoincrement=False)
    s3_scaler_uri = Column(VARCHAR(191), nullable=False, autoincrement=False)
    input_table_name = Column(VARCHAR(191), nullable=False, autoincrement=False)
    input_table_cols = Column(VARCHAR(191), nullable=False, autoincrement=False)
    trained_on = Column(TIMESTAMP, nullable=False, autoincrement=False)
    is_stacked = Column(INTEGER, autoincrement=False)
    is_generic = Column(INTEGER, autoincrement=False)
    team_id = Column(INTEGER, autoincrement=False)
    name = Column(VARCHAR(191), autoincrement=False)
    output_table_name = Column(VARCHAR(191), autoincrement=False)
    output_table_col = Column(VARCHAR(191), autoincrement=False)
    description = Column(VARCHAR(191), autoincrement=False)
    project_type = Column(VARCHAR(50), autoincrement=False)
    parent_model_id = Column(INTEGER, autoincrement=False)
    order = Column(INTEGER, autoincrement=False)
    s3_python_uri = Column(TEXT, autoincrement=False)
    python_update_version = Column(TEXT, autoincrement=False)
    python_update_version  = Column(INTEGER, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpCurveDw(PrimaryBase):
    __tablename__ = 'inp_curve_dw'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    name = Column(VARCHAR(250), nullable=False, autoincrement=False)
    type = Column(VARCHAR(25), nullable=False, autoincrement=False)
    xvalue = Column('x-value', DOUBLE_PRECISION, autoincrement=False)
    yvalue = Column('y-value', DOUBLE_PRECISION, autoincrement=False)
    description = Column(TEXT, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class PipeCostLookup(PrimaryBase):
    __tablename__ = 'pipe_cost_lookup'
    __table_args__ = {'schema': 'public'}
    
    column_not_exist_in_db = Column(INTEGER, primary_key=True) # Needed to circumvent primary key requirement in sqlalchemy
    object_id = Column(INTEGER, nullable=False, autoincrement=False)
    min_flow_area = Column(INTEGER, nullable=False, autoincrement=False)
    max_flow_area = Column(INTEGER, nullable=False, autoincrement=False)
    lnft_unit_cost_under_pavement = Column(INTEGER, nullable=False, autoincrement=False)
    lnft_unit_cost_not_under_pavement = Column(INTEGER, nullable=False, autoincrement=False)
    lnft_cost_near_rail = Column(INTEGER, nullable=False, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportNodeCof(PrimaryBase):
    __tablename__ = 'spark_report_node_cof'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    tmdl_imp = Column(NUMERIC, autoincrement=False)
    crit_imp = Column(NUMERIC, autoincrement=False)
    trans_imp = Column(NUMERIC, autoincrement=False)
    utility_imp = Column(NUMERIC, autoincrement=False)
    eco_imp = Column(NUMERIC, autoincrement=False)
    severity_imp = Column(NUMERIC, autoincrement=False)
    repl_cost = Column(NUMERIC, autoincrement=False)
    proxi_road = Column(NUMERIC, autoincrement=False)
    proxi_rail = Column(NUMERIC, autoincrement=False)
    proxi_gas = Column(NUMERIC, autoincrement=False)
    proxi_electric = Column(NUMERIC, autoincrement=False)
    cof = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class RainfallAnalysis(PrimaryBase):
    __tablename__ = 'rainfall_analysis'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    group = Column(VARCHAR(191), nullable=False, autoincrement=False)
    min_interevent = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    event_threshold = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    extend_event_preceeding = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    extend_event_following = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    limit_event_from = Column(TIMESTAMP, autoincrement=False)
    limit_event_to = Column(TIMESTAMP, autoincrement=False)
    exclude_audit_exceptions = Column(BOOLEAN, nullable=False, autoincrement=False)
    clear_existing_events = Column(BOOLEAN, nullable=False, autoincrement=False)
    noaa_atlas_14_frequency_events = Column(BOOLEAN, nullable=False, autoincrement=False)
    auto_simulation = Column(BOOLEAN, nullable=False, autoincrement=False)
    perform_forecasted_rainfall_event_analysis = Column(BOOLEAN, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    updated_at = Column(TIMESTAMP, nullable=False, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkRptConduitSurchargeSummaries(PrimaryBase):
    __tablename__ = 'spark_rpt_conduit_surcharge_summaries'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    order = Column(INTEGER, primary_key=True, autoincrement=False)
    conduit = Column(TEXT, primary_key=True, autoincrement=False)
    hours_both_ends_full = Column(NUMERIC, autoincrement=False)
    hours_upstream_full = Column(NUMERIC, autoincrement=False)
    hours_downstream_full = Column(NUMERIC, autoincrement=False)
    hours_above_normal_flow = Column(NUMERIC, autoincrement=False)
    hours_capacity_limited = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpDivider(PrimaryBase):
    __tablename__ = 'inp_divider'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    name = Column(VARCHAR(250), autoincrement=False)
    elev = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    div_link = Column(VARCHAR(75), autoincrement=False)
    type = Column(VARCHAR(20), nullable=False, autoincrement=False)
    q_min = Column(DOUBLE_PRECISION, autoincrement=False)
    d_curve = Column(VARCHAR(75), autoincrement=False)
    ht = Column(DOUBLE_PRECISION, autoincrement=False)
    cd = Column(DOUBLE_PRECISION, autoincrement=False)
    y_max = Column(DOUBLE_PRECISION, autoincrement=False)
    y0 = Column(DOUBLE_PRECISION, autoincrement=False)
    y_sur = Column(DOUBLE_PRECISION, autoincrement=False)
    apond = Column(DOUBLE_PRECISION, autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
    mukey = Column(VARCHAR(191), autoincrement=False)
    site_id = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class PerformanceIndicators(PrimaryBase):
    __tablename__ = 'performance_indicators'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    monthly_recurring_revenue = Column(NUMERIC(8, 2), nullable=False, autoincrement=False)
    yearly_recurring_revenue = Column(NUMERIC(8, 2), nullable=False, autoincrement=False)
    daily_volume = Column(NUMERIC(8, 2), nullable=False, autoincrement=False)
    new_users = Column(INTEGER, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportNodesDw(PrimaryBase):
    __tablename__ = 'spark_report_nodes_dw'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    order = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    datetime = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    layer = Column(TEXT, autoincrement=False)
    date = Column(DATE, nullable=False, autoincrement=False)
    time = Column(TIME, nullable=False, autoincrement=False)
    demand = Column(NUMERIC, autoincrement=False)
    head = Column(NUMERIC, autoincrement=False)
    pressure = Column(NUMERIC, autoincrement=False)
    quality_parameter = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    is_forecasted = Column(BOOLEAN, primary_key=True, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpJunctionDw(PrimaryBase):
    __tablename__ = 'inp_junction_dw'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    name = Column(VARCHAR(250), autoincrement=False)
    descript = Column(VARCHAR(1024), autoincrement=False)
    elevation = Column(VARCHAR(25), autoincrement=False)
    base_demand = Column(VARCHAR(25), autoincrement=False)
    demand_pat = Column(VARCHAR(25), autoincrement=False)
    demand_cat = Column(VARCHAR(25), autoincrement=False)
    emit_coef = Column(VARCHAR(25), autoincrement=False)
    init_qual = Column(VARCHAR(25), autoincrement=False)
    src_qual = Column(VARCHAR(25), autoincrement=False)
    src_pattern = Column(VARCHAR(25), autoincrement=False)
    src_type = Column(VARCHAR(25), autoincrement=False)
    project_id = Column(INTEGER, autoincrement=False)
    site_id = Column(VARCHAR(191), autoincrement=False)
    a_type = Column(VARCHAR(191), autoincrement=False)
    a_status = Column(VARCHAR(191), autoincrement=False)
    a_pressure_zone = Column(VARCHAR(191), autoincrement=False)
    a_dma = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportLinksDw1d(PrimaryBase):
    __tablename__ = 'spark_report_links_dw_1d'
    __table_args__ = {'schema': 'predictions'}
    
    bucket = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    layer = Column(TEXT, autoincrement=False)
    state = Column(TEXT, autoincrement=False)
    avg_flow = Column(NUMERIC, autoincrement=False)
    avg_velocity = Column(NUMERIC, autoincrement=False)
    avg_headloss = Column(NUMERIC, autoincrement=False)
    avg_setting = Column(NUMERIC, autoincrement=False)
    avg_reaction = Column(NUMERIC, autoincrement=False)
    avg_f_factor = Column(NUMERIC, autoincrement=False)
    min_flow = Column(NUMERIC, autoincrement=False)
    min_velocity = Column(NUMERIC, autoincrement=False)
    min_headloss = Column(NUMERIC, autoincrement=False)
    min_setting = Column(NUMERIC, autoincrement=False)
    min_reaction = Column(NUMERIC, autoincrement=False)
    min_f_factor = Column(NUMERIC, autoincrement=False)
    max_flow = Column(NUMERIC, autoincrement=False)
    max_velocity = Column(NUMERIC, autoincrement=False)
    max_headloss = Column(NUMERIC, autoincrement=False)
    max_setting = Column(NUMERIC, autoincrement=False)
    max_reaction = Column(NUMERIC, autoincrement=False)
    max_f_factor = Column(NUMERIC, autoincrement=False)
    is_forecasted = Column(BOOLEAN, primary_key=True, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class LandUseCodeScores(PrimaryBase):
    __tablename__ = 'land_use_code_scores'
    __table_args__ = {'schema': 'public'}
    
    column_not_exist_in_db = Column(INTEGER, primary_key=True) # Needed to circumvent primary key requirement in sqlalchemy
    lu_code = Column(INTEGER, autoincrement=False)
    lu_score = Column(INTEGER, autoincrement=False)
    name_type = Column(VARCHAR(200), autoincrement=False)
    description = Column(TEXT, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class AutoSnapshotSchedule(PrimaryBase):
    __tablename__ = 'auto_snapshot_schedule'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(VARCHAR(191), autoincrement=False)
    repetition = Column(VARCHAR(191), autoincrement=False)
    time = Column(VARCHAR(191), autoincrement=False)
    start_date = Column(VARCHAR(191), autoincrement=False)
    end_date = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT, SMALLINT
from base import PrimaryBase

class ApiTokens(PrimaryBase):
    __tablename__ = 'api_tokens'
    __table_args__ = {'schema': 'public'}
    
    id = Column(VARCHAR(191), primary_key=True, autoincrement=False)
    user_id = Column(INTEGER, nullable=False, autoincrement=False)
    name = Column(VARCHAR(191), nullable=False, autoincrement=False)
    token = Column(VARCHAR(100), nullable=False, autoincrement=False)
    meta = Column('metadata', TEXT, nullable=False, autoincrement=False)
    transient = Column(SMALLINT, nullable=False, autoincrement=False)
    last_used_at = Column(TIMESTAMP, autoincrement=False)
    expires_at = Column(TIMESTAMP, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpTemperature(PrimaryBase):
    __tablename__ = 'inp_temperature'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    data_type = Column(VARCHAR(30), autoincrement=False)
    file_name = Column(VARCHAR(255), autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
    start_reading_at = Column(VARCHAR(25), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class NonRevenueWater(PrimaryBase):
    __tablename__ = 'non_revenue_water'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    year = Column(INTEGER, nullable=False, autoincrement=False)
    percentage = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, JSONB
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Features(PrimaryBase):
    __tablename__ = 'features'
    __table_args__ = {'schema': 'cswr'}
    
    id = Column(UUID, primary_key=True, autoincrement=False)
    fid = Column(INTEGER, nullable=False, autoincrement=False)
    service = Column(TEXT, nullable=False, autoincrement=False)
    layer = Column(TEXT, nullable=False, autoincrement=False)
    geometry = Column(TEXT, autoincrement=False)
    properties = Column(JSONB, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    category = Column(VARCHAR(19), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportLinkBre(PrimaryBase):
    __tablename__ = 'spark_report_link_bre'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    bre = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class CustomerSurveyForm(PrimaryBase):
    __tablename__ = 'customer_survey_form'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    account_number = Column(VARCHAR(191), nullable=False, autoincrement=False)
    project_id = Column(INTEGER, autoincrement=False)
    first_name = Column(VARCHAR(191), autoincrement=False)
    last_name = Column(VARCHAR(191), autoincrement=False)
    phone = Column(VARCHAR(25), autoincrement=False)
    email = Column(VARCHAR(191), autoincrement=False)
    address = Column(VARCHAR(500), autoincrement=False)
    occupancy_type = Column(VARCHAR(10), autoincrement=False)
    material = Column(VARCHAR(191), autoincrement=False)
    installation_date = Column(DATE, autoincrement=False)
    source_of_info = Column(VARCHAR(191), autoincrement=False)
    photo = Column(TEXT, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class LikelyLeakLocations(PrimaryBase):
    __tablename__ = 'likely_leak_locations'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    leak_id = Column(INTEGER, nullable=False, autoincrement=False)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    service_area = Column(VARCHAR(191), nullable=False, autoincrement=False)
    main_pipe_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    main_pipe_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    service_line_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    service_line_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    service_connection_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    service_connection_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    valve_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    valve_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    hydrant_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    hydrant_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    meter_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    meter_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    curb_stop_flow_rate = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    curb_stop_leak_count = Column(INTEGER, nullable=False, autoincrement=False)
    total_flow = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportSubcatchments30d(PrimaryBase):
    __tablename__ = 'spark_report_subcatchments_30d'
    __table_args__ = {'schema': 'predictions'}
    
    bucket = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    is_forecasted = Column(BOOLEAN, primary_key=True, autoincrement=False)
    avg_rainfall = Column(NUMERIC, autoincrement=False)
    avg_snow = Column(NUMERIC, autoincrement=False)
    avg_evap = Column(NUMERIC, autoincrement=False)
    avg_infil = Column(NUMERIC, autoincrement=False)
    avg_runoff = Column(NUMERIC, autoincrement=False)
    avg_gw_flow = Column(NUMERIC, autoincrement=False)
    avg_gw_elev = Column(NUMERIC, autoincrement=False)
    avg_soil_moist = Column(NUMERIC, autoincrement=False)
    avg_washoff = Column(NUMERIC, autoincrement=False)
    min_rainfall = Column(NUMERIC, autoincrement=False)
    min_snow = Column(NUMERIC, autoincrement=False)
    min_evap = Column(NUMERIC, autoincrement=False)
    min_infil = Column(NUMERIC, autoincrement=False)
    min_runoff = Column(NUMERIC, autoincrement=False)
    min_gw_flow = Column(NUMERIC, autoincrement=False)
    min_gw_elev = Column(NUMERIC, autoincrement=False)
    min_soil_moist = Column(NUMERIC, autoincrement=False)
    min_washoff = Column(NUMERIC, autoincrement=False)
    max_rainfall = Column(NUMERIC, autoincrement=False)
    max_snow = Column(NUMERIC, autoincrement=False)
    max_evap = Column(NUMERIC, autoincrement=False)
    max_infil = Column(NUMERIC, autoincrement=False)
    max_runoff = Column(NUMERIC, autoincrement=False)
    max_gw_flow = Column(NUMERIC, autoincrement=False)
    max_gw_elev = Column(NUMERIC, autoincrement=False)
    max_soil_moist = Column(NUMERIC, autoincrement=False)
    max_washoff = Column(NUMERIC, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class TeamSubscriptions(PrimaryBase):
    __tablename__ = 'team_subscriptions'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    team_id = Column(INTEGER, nullable=False, autoincrement=False)
    name = Column(VARCHAR(191), nullable=False, autoincrement=False)
    stripe_id = Column(VARCHAR(191), nullable=False, autoincrement=False)
    stripe_plan = Column(VARCHAR(191), nullable=False, autoincrement=False)
    quantity = Column(INTEGER, nullable=False, autoincrement=False)
    trial_ends_at = Column(TIMESTAMP, autoincrement=False)
    ends_at = Column(TIMESTAMP, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    stripe_status = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, ARRAY
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportNodes1d(PrimaryBase):
    __tablename__ = 'spark_report_nodes_1d'
    __table_args__ = {'schema': 'predictions'}
    
    bucket = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    is_forecasted = Column(BOOLEAN, primary_key=True, autoincrement=False)
    avg_depth = Column(NUMERIC, autoincrement=False)
    avg_head = Column(NUMERIC, autoincrement=False)
    avg_volume = Column(NUMERIC, autoincrement=False)
    avg_lateral = Column(NUMERIC, autoincrement=False)
    avg_inflow = Column(NUMERIC, autoincrement=False)
    avg_flooding = Column(NUMERIC, autoincrement=False)
    min_depth = Column(NUMERIC, autoincrement=False)
    min_head = Column(NUMERIC, autoincrement=False)
    min_volume = Column(NUMERIC, autoincrement=False)
    min_lateral = Column(NUMERIC, autoincrement=False)
    min_inflow = Column(NUMERIC, autoincrement=False)
    min_flooding = Column(NUMERIC, autoincrement=False)
    max_depth = Column(NUMERIC, autoincrement=False)
    max_head = Column(NUMERIC, autoincrement=False)
    max_volume = Column(NUMERIC, autoincrement=False)
    max_lateral = Column(NUMERIC, autoincrement=False)
    max_inflow = Column(NUMERIC, autoincrement=False)
    max_flooding = Column(NUMERIC, autoincrement=False)
    avg_qualities = Column(ARRAY(NUMERIC), autoincrement=False)
    min_qualities = Column(ARRAY(NUMERIC), autoincrement=False)
    max_qualities = Column(ARRAY(NUMERIC), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class RainfallAnalysisGaugeResults(PrimaryBase):
    __tablename__ = 'rainfall_analysis_gauge_results'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    rainfall_analysis_gauge_id = Column(INTEGER, nullable=False, autoincrement=False)
    start_date_time = Column(TIMESTAMP, nullable=False, autoincrement=False)
    end_date_time = Column(TIMESTAMP, nullable=False, autoincrement=False)
    duration = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    max_rainfall = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    min_rainfall = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    mean_rainfall = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    total_rainfall_volume = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    rainfall_period = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class PasswordResets(PrimaryBase):
    __tablename__ = 'password_resets'
    __table_args__ = {'schema': 'public'}
    
    column_not_exist_in_db = Column(INTEGER, primary_key=True) # Needed to circumvent primary key requirement in sqlalchemy
    email = Column(VARCHAR(191), nullable=False, autoincrement=False)
    token = Column(VARCHAR(191), nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpSimpleJunctionAm(PrimaryBase):
    __tablename__ = 'inp_simple_junction_am'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    city = Column(VARCHAR(191), autoincrement=False)
    name = Column(VARCHAR(191), autoincrement=False)
    is_ineligib = Column(VARCHAR(191), autoincrement=False)
    is_cond_est = Column(VARCHAR(191), autoincrement=False)
    source = Column(VARCHAR(191), autoincrement=False)
    comments = Column(VARCHAR(191), autoincrement=False)
    watershed_name = Column(VARCHAR(191), autoincrement=False)
    owner = Column(VARCHAR(191), autoincrement=False)
    ins_date = Column(DATE, autoincrement=False)
    dim1 = Column(VARCHAR(191), autoincrement=False)
    dim2 = Column(VARCHAR(191), autoincrement=False)
    stru_type = Column(VARCHAR(191), autoincrement=False)
    material = Column(VARCHAR(191), autoincrement=False)
    inv_ele = Column(VARCHAR(191), autoincrement=False)
    rim_ele = Column(VARCHAR(191), autoincrement=False)
    dep_cover = Column(VARCHAR(191), autoincrement=False)
    jnt_type = Column(VARCHAR(191), autoincrement=False)
    ass_us_str = Column(VARCHAR(191), autoincrement=False)
    ass_ds_str = Column(VARCHAR(191), autoincrement=False)
    lat_con = Column(VARCHAR(191), autoincrement=False)
    bed_cond = Column(VARCHAR(191), autoincrement=False)
    trench_bf = Column(VARCHAR(191), autoincrement=False)
    des_life = Column(VARCHAR(191), autoincrement=False)
    des_storm = Column(VARCHAR(191), autoincrement=False)
    function = Column(VARCHAR(191), autoincrement=False)
    thickness = Column(VARCHAR(191), autoincrement=False)
    coating = Column(VARCHAR(191), autoincrement=False)
    lining = Column(VARCHAR(191), autoincrement=False)
    status = Column(VARCHAR(191), autoincrement=False)
    line_cond = Column(VARCHAR(191), autoincrement=False)
    ext_coat_cond = Column(VARCHAR(191), autoincrement=False)
    ht_bedding = Column(VARCHAR(191), autoincrement=False)
    des_str_stru = Column(VARCHAR(191), autoincrement=False)
    str_ins_date = Column(VARCHAR(191), autoincrement=False)
    ext_coat_age = Column(VARCHAR(191), autoincrement=False)
    struc_vint = Column(VARCHAR(191), autoincrement=False)
    struc_class = Column(VARCHAR(191), autoincrement=False)
    us_st_cond = Column(VARCHAR(191), autoincrement=False)
    ds_st_cond = Column(VARCHAR(191), autoincrement=False)
    dis_mater = Column(VARCHAR(191), autoincrement=False)
    soil_type = Column(VARCHAR(191), autoincrement=False)
    gw_table = Column(VARCHAR(191), autoincrement=False)
    location = Column(VARCHAR(191), autoincrement=False)
    dead_load = Column(VARCHAR(191), autoincrement=False)
    live_load = Column(VARCHAR(191), autoincrement=False)
    av_preci_int = Column(VARCHAR(191), autoincrement=False)
    av_preci_dur = Column(VARCHAR(191), autoincrement=False)
    frost_pen = Column(VARCHAR(191), autoincrement=False)
    s_corro = Column(VARCHAR(191), autoincrement=False)
    near_trees = Column(VARCHAR(191), autoincrement=False)
    pipe_dir = Column(VARCHAR(191), autoincrement=False)
    ext_temp = Column(VARCHAR(191), autoincrement=False)
    his_ext_eve = Column(VARCHAR(191), autoincrement=False)
    catch_area = Column(VARCHAR(191), autoincrement=False)
    ws_int = Column(VARCHAR(191), autoincrement=False)
    wet_dry_cyc = Column(VARCHAR(191), autoincrement=False)
    nn_homo_soil = Column(VARCHAR(191), autoincrement=False)
    aci_runoff = Column(VARCHAR(191), autoincrement=False)
    soil_res = Column(VARCHAR(191), autoincrement=False)
    soil_dis = Column(VARCHAR(191), autoincrement=False)
    soil_sul = Column(VARCHAR(191), autoincrement=False)
    soil_ph = Column(VARCHAR(191), autoincrement=False)
    soil_moi_ret = Column(VARCHAR(191), autoincrement=False)
    st_curr = Column(VARCHAR(191), autoincrement=False)
    tidal_inf = Column(VARCHAR(191), autoincrement=False)
    av_flow_vel = Column(VARCHAR(191), autoincrement=False)
    min_flow_vel = Column(VARCHAR(191), autoincrement=False)
    max_flow_vel = Column(VARCHAR(191), autoincrement=False)
    of_freq = Column(VARCHAR(191), autoincrement=False)
    surcharge = Column(VARCHAR(191), autoincrement=False)
    inflow_infill = Column(VARCHAR(191), autoincrement=False)
    exfiltration = Column(VARCHAR(191), autoincrement=False)
    ave_pres = Column(VARCHAR(191), autoincrement=False)
    min_pres = Column(VARCHAR(191), autoincrement=False)
    max_pres = Column(VARCHAR(191), autoincrement=False)
    known_leak = Column(VARCHAR(191), autoincrement=False)
    deb_level = Column(VARCHAR(191), autoincrement=False)
    sed_level = Column(VARCHAR(191), autoincrement=False)
    smell_level = Column(VARCHAR(191), autoincrement=False)
    stag_water = Column(VARCHAR(191), autoincrement=False)
    flooding = Column(VARCHAR(191), autoincrement=False)
    maint_fre = Column(VARCHAR(191), autoincrement=False)
    outelet_prot = Column(VARCHAR(191), autoincrement=False)
    conv_cap = Column(VARCHAR(191), autoincrement=False)
    mode_res_av = Column(VARCHAR(191), autoincrement=False)
    res_2yr = Column(VARCHAR(191), autoincrement=False)
    res_5yr = Column(VARCHAR(191), autoincrement=False)
    res_10yr = Column(VARCHAR(191), autoincrement=False)
    res_25yr = Column(VARCHAR(191), autoincrement=False)
    res_50yr = Column(VARCHAR(191), autoincrement=False)
    res_100yr = Column(VARCHAR(191), autoincrement=False)
    res_500yr = Column(VARCHAR(191), autoincrement=False)
    lt_sim_res = Column(VARCHAR(191), autoincrement=False)
    pacp_cond = Column(VARCHAR(191), autoincrement=False)
    mt_rec = Column(VARCHAR(191), autoincrement=False)
    cctv_rec = Column(VARCHAR(191), autoincrement=False)
    ren_rec = Column(VARCHAR(191), autoincrement=False)
    fail_rec = Column(VARCHAR(191), autoincrement=False)
    comp_rec = Column(VARCHAR(191), autoincrement=False)
    cap_cost = Column(VARCHAR(191), autoincrement=False)
    yr_om_cost = Column(VARCHAR(191), autoincrement=False)
    con_spec = Column(VARCHAR(191), autoincrement=False)
    lof = Column(VARCHAR(191), autoincrement=False)
    eco_imp = Column(VARCHAR(191), autoincrement=False)
    trans_imp = Column(VARCHAR(191), autoincrement=False)
    crit_imp = Column(VARCHAR(191), autoincrement=False)
    utility_imp = Column(VARCHAR(191), autoincrement=False)
    tmdl_imp = Column(VARCHAR(191), autoincrement=False)
    under_pave = Column(VARCHAR(191), autoincrement=False)
    proxi_rail = Column(VARCHAR(191), autoincrement=False)
    repl_cost = Column(VARCHAR(191), autoincrement=False)
    cof = Column(VARCHAR(191), autoincrement=False)
    bre = Column(VARCHAR(191), autoincrement=False)
    cip_id = Column(VARCHAR(191), autoincrement=False)
    max_allow_vel = Column(VARCHAR(191), autoincrement=False)
    max_allow_pres = Column(VARCHAR(191), autoincrement=False)
    mt_score = Column(VARCHAR(191), autoincrement=False)
    vs_inspect_rec = Column(VARCHAR(191), autoincrement=False)
    vs_inspect_score = Column(VARCHAR(191), autoincrement=False)
    em_inspect_rec = Column(VARCHAR(191), autoincrement=False)
    em_inspect_score = Column(VARCHAR(191), autoincrement=False)
    cctv_score = Column(VARCHAR(191), autoincrement=False)
    ac_inspect_rec = Column(VARCHAR(191), autoincrement=False)
    ac_inspect_score = Column(VARCHAR(191), autoincrement=False)
    ultra_test_rec = Column(VARCHAR(191), autoincrement=False)
    ultra_test_score = Column(VARCHAR(191), autoincrement=False)
    pipe_map_rec = Column(VARCHAR(191), autoincrement=False)
    pipe_map_score = Column(VARCHAR(191), autoincrement=False)
    radio_test_rec = Column(VARCHAR(191), autoincrement=False)
    radio_test_score = Column(VARCHAR(191), autoincrement=False)
    thermo_test_rec = Column(VARCHAR(191), autoincrement=False)
    thermo_test_score = Column(VARCHAR(191), autoincrement=False)
    other_test_rec = Column(VARCHAR(191), autoincrement=False)
    other_test_score = Column(VARCHAR(191), autoincrement=False)
    ren_score = Column(VARCHAR(191), autoincrement=False)
    fail_score = Column(VARCHAR(191), autoincrement=False)
    comp_score = Column(VARCHAR(191), autoincrement=False)
    rem_use_life = Column(VARCHAR(191), autoincrement=False)
    watershed_id = Column(VARCHAR(191), autoincrement=False)
    huc_12_id = Column(VARCHAR(191), autoincrement=False)
    land_use = Column(VARCHAR(191), autoincrement=False)
    tree_canopy = Column(VARCHAR(191), autoincrement=False)
    last_inspection_date = Column(VARCHAR(191), autoincrement=False)
    construction_performance_index = Column(VARCHAR(191), autoincrement=False)
    mukey = Column(VARCHAR(191), autoincrement=False)
    cond_comments = Column(VARCHAR(191), autoincrement=False)
    proxi_road = Column(VARCHAR(191), autoincrement=False)
    proxi_gas = Column(VARCHAR(191), autoincrement=False)
    proxi_elec = Column(VARCHAR(191), autoincrement=False)
    severity_imp = Column(VARCHAR(191), autoincrement=False)
    pred_invelev = Column(VARCHAR(191), autoincrement=False)
    pred_rimelev = Column(VARCHAR(191), autoincrement=False)
    pred_material = Column(VARCHAR(191), autoincrement=False)
    pred_dim1 = Column(VARCHAR(191), autoincrement=False)
    pred_dim2 = Column(VARCHAR(191), autoincrement=False)
    project_id = Column(INTEGER, autoincrement=False)
    neerstndstr = Column(VARCHAR(191), autoincrement=False)
    is_pred_material = Column(VARCHAR(191), autoincrement=False)
    is_pred_dim1 = Column(VARCHAR(191), autoincrement=False)
    is_pred_dim2 = Column(VARCHAR(191), autoincrement=False)
    is_pred_rimelev = Column(VARCHAR(191), autoincrement=False)
    is_pred_invelev = Column(VARCHAR(191), autoincrement=False)
    pred_flow_area = Column(VARCHAR(191), autoincrement=False)
    is_pred_flow_area = Column(VARCHAR(191), autoincrement=False)
    pred_ins_date = Column(DATE, autoincrement=False)
    is_pred_ins_date = Column(VARCHAR(191), autoincrement=False)
    enviro_imp = Column(INTEGER, autoincrement=False)
    lu_imp = Column(INTEGER, autoincrement=False)
    flood_risk = Column(NUMERIC(8, 2), autoincrement=False)
    stream_risk = Column(NUMERIC(8, 2), autoincrement=False)
    storm_sewer_risk = Column(NUMERIC(8, 2), autoincrement=False)
    groundwater_index_risk = Column(NUMERIC(8, 2), autoincrement=False)
    infiltration_risk = Column(NUMERIC(8, 2), autoincrement=False)
    inflow_risk = Column(NUMERIC(8, 2), autoincrement=False)
    basin_index_risk = Column(NUMERIC(8, 2), autoincrement=False)
    rehab = Column(BOOLEAN, autoincrement=False)
    rehab_date = Column(DATE, autoincrement=False)
    rehab_material = Column(VARCHAR(191), autoincrement=False)
    condition_date = Column(DATE, autoincrement=False)
    state = Column(VARCHAR(191), autoincrement=False)
    account_id = Column(VARCHAR(191), autoincrement=False)
    rehab_action = Column(VARCHAR(191), autoincrement=False)
    frost_depth = Column(DOUBLE_PRECISION, autoincrement=False)
    gr_water_lvl_frm_land_surf = Column(DOUBLE_PRECISION, autoincrement=False)
    county = Column(VARCHAR(191), autoincrement=False)
    country = Column(VARCHAR(191), autoincrement=False)
    gr_water_station_url = Column(TEXT, autoincrement=False)
    asset_name = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpEvaporation(PrimaryBase):
    __tablename__ = 'inp_evaporation'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    type = Column(VARCHAR(25), autoincrement=False)
    field_value = Column(VARCHAR(50), autoincrement=False)
    p1 = Column(DOUBLE_PRECISION, autoincrement=False)
    p2 = Column(DOUBLE_PRECISION, autoincrement=False)
    p3 = Column(DOUBLE_PRECISION, autoincrement=False)
    p4 = Column(DOUBLE_PRECISION, autoincrement=False)
    p5 = Column(DOUBLE_PRECISION, autoincrement=False)
    p6 = Column(DOUBLE_PRECISION, autoincrement=False)
    p7 = Column(DOUBLE_PRECISION, autoincrement=False)
    p8 = Column(DOUBLE_PRECISION, autoincrement=False)
    p9 = Column(DOUBLE_PRECISION, autoincrement=False)
    p10 = Column(DOUBLE_PRECISION, autoincrement=False)
    p11 = Column(DOUBLE_PRECISION, autoincrement=False)
    p12 = Column(DOUBLE_PRECISION, autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class UserProjectMappingOld(PrimaryBase):
    __tablename__ = 'user_project_mapping_old'
    __table_args__ = {'schema': 'public'}
    
    user_project_mapping = Column(INTEGER, primary_key=True, autoincrement=False)
    user_id = Column(INTEGER, nullable=False, autoincrement=False)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class CofModels(PrimaryBase):
    __tablename__ = 'cof_models'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    name = Column(VARCHAR(191), nullable=False, autoincrement=False)
    description = Column(TEXT, autoincrement=False)
    type = Column(VARCHAR(191), nullable=False, autoincrement=False)
    path = Column(VARCHAR(191), nullable=False, autoincrement=False)
    is_generic = Column(INTEGER, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, SMALLINT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpStorage(PrimaryBase):
    __tablename__ = 'inp_storage'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    name = Column(VARCHAR(250), autoincrement=False)
    invert_elev = Column(VARCHAR(25), autoincrement=False)
    max_depth = Column(VARCHAR(25), autoincrement=False)
    init_depth = Column(VARCHAR(25), autoincrement=False)
    type = Column(VARCHAR(25), autoincrement=False)
    a_curve = Column(VARCHAR(75), autoincrement=False)
    a1 = Column(DOUBLE_PRECISION, autoincrement=False)
    a2 = Column(DOUBLE_PRECISION, autoincrement=False)
    a0 = Column(DOUBLE_PRECISION, autoincrement=False)
    apond = Column(SMALLINT, autoincrement=False)
    f_evap = Column(DOUBLE_PRECISION, autoincrement=False)
    psi = Column(DOUBLE_PRECISION, autoincrement=False)
    ksat = Column(DOUBLE_PRECISION, autoincrement=False)
    imd = Column(DOUBLE_PRECISION, autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
    mukey = Column(VARCHAR(191), autoincrement=False)
    site_id = Column(VARCHAR(191), autoincrement=False)
    storage_holding_capacity = Column(DOUBLE_PRECISION, autoincrement=False)
    storage_type = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Projects(PrimaryBase):
    __tablename__ = 'projects'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    name = Column(VARCHAR(100), nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    projection = Column(INTEGER, autoincrement=False)
    type = Column(VARCHAR(10), autoincrement=False)
    map_lat = Column(VARCHAR(30), autoincrement=False)
    map_lng = Column(VARCHAR(30), autoincrement=False)
    map_zoom = Column(VARCHAR(30), autoincrement=False)
    map_id = Column(INTEGER, autoincrement=False)
    inp_uploaded_at = Column(TIMESTAMP, autoincrement=False)
    inp_processed_at = Column(TIMESTAMP, autoincrement=False)
    progress = Column(VARCHAR(255), autoincrement=False)
    group = Column(VARCHAR(20), nullable=False, autoincrement=False)
    lofp = Column(DOUBLE_PRECISION, autoincrement=False)
    cofp = Column(DOUBLE_PRECISION, autoincrement=False)
    copy_success = Column(INTEGER, autoincrement=False)
    imp_transpo = Column(VARCHAR(191), autoincrement=False)
    imp_fac = Column(VARCHAR(191), autoincrement=False)
    imp_util_gas = Column(VARCHAR(191), autoincrement=False)
    imp_util_electric = Column(VARCHAR(191), autoincrement=False)
    imp_util_cable = Column(VARCHAR(191), autoincrement=False)
    imp_util_internet = Column(VARCHAR(191), autoincrement=False)
    imp_util_water = Column(VARCHAR(191), autoincrement=False)
    imp_util_wastewater = Column(VARCHAR(191), autoincrement=False)
    imp_util_stormwater = Column(VARCHAR(191), autoincrement=False)
    imp_util_other1 = Column(VARCHAR(191), autoincrement=False)
    imp_util_other2 = Column(VARCHAR(191), autoincrement=False)
    tmdl_contrib = Column(VARCHAR(191), autoincrement=False)
    pipe_unit_cost = Column(VARCHAR(191), autoincrement=False)
    struc_unit_cost = Column(VARCHAR(191), autoincrement=False)
    preferred_simulator = Column(VARCHAR(191), autoincrement=False)
    settings = Column(TEXT, autoincrement=False)
    deleted_at = Column(TIMESTAMP, autoincrement=False)
    imp_layers = Column(VARCHAR(191), autoincrement=False)
    team_id = Column(VARCHAR(191), autoincrement=False)
    dem_file = Column(VARCHAR(191), autoincrement=False)
    use_risk_map = Column(VARCHAR(191), nullable=False, autoincrement=False)
    cof_counties_array = Column(TEXT, autoincrement=False)
    cof_model_array = Column(VARCHAR(191), autoincrement=False)
    cof_model_id = Column(INTEGER, autoincrement=False)
    lof_model_array = Column(VARCHAR(191), autoincrement=False)
    lof_model_id = Column(INTEGER, autoincrement=False)
    dwf_filter_by = Column(VARCHAR(191), autoincrement=False)
    dwf_start_date = Column(VARCHAR(191), autoincrement=False)
    dwf_end_date = Column(VARCHAR(191), autoincrement=False)
    dwf_model_id = Column(INTEGER, autoincrement=False)
    dwf_simulation_id = Column(INTEGER, autoincrement=False)
    wwf_filter_by = Column(VARCHAR(191), autoincrement=False)
    wwf_start_date = Column(INTEGER, autoincrement=False)
    wwf_end_date = Column(INTEGER, autoincrement=False)
    wwf_model_id = Column(INTEGER, autoincrement=False)
    wwf_event_id = Column(INTEGER, autoincrement=False)
    wwf_simulation_id = Column(INTEGER, autoincrement=False)
    rainfall_analysis_id_filter = Column(INTEGER, autoincrement=False)
    rainfall_analysis_gauge_id_filter = Column(INTEGER, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, SMALLINT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Notifications(PrimaryBase):
    __tablename__ = 'notifications'
    __table_args__ = {'schema': 'public'}
    
    id = Column(VARCHAR(191), primary_key=True, autoincrement=False)
    user_id = Column(INTEGER, nullable=False, autoincrement=False)
    created_by = Column(INTEGER, autoincrement=False)
    icon = Column(VARCHAR(50), autoincrement=False)
    body = Column(TEXT, nullable=False, autoincrement=False)
    action_text = Column(VARCHAR(191), autoincrement=False)
    action_url = Column(TEXT, autoincrement=False)
    read = Column(SMALLINT, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, SMALLINT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Users(PrimaryBase):
    __tablename__ = 'users'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    name = Column(VARCHAR(191), nullable=False, autoincrement=False)
    email = Column(VARCHAR(191), nullable=False, autoincrement=False)
    email_verified_at = Column(TIMESTAMP, autoincrement=False)
    password = Column(VARCHAR(191), nullable=False, autoincrement=False)
    remember_token = Column(VARCHAR(100), autoincrement=False)
    photo_url = Column(TEXT, autoincrement=False)
    uses_two_factor_auth = Column(SMALLINT, nullable=False, autoincrement=False)
    authy_id = Column(VARCHAR(191), autoincrement=False)
    country_code = Column(VARCHAR(10), autoincrement=False)
    phone = Column(VARCHAR(25), autoincrement=False)
    two_factor_reset_code = Column(VARCHAR(100), autoincrement=False)
    current_team_id = Column(INTEGER, autoincrement=False)
    stripe_id = Column(VARCHAR(191), autoincrement=False)
    current_billing_plan = Column(VARCHAR(191), autoincrement=False)
    card_brand = Column(VARCHAR(191), autoincrement=False)
    card_last_four = Column(VARCHAR(191), autoincrement=False)
    card_country = Column(VARCHAR(191), autoincrement=False)
    billing_address = Column(VARCHAR(191), autoincrement=False)
    billing_address_line_2 = Column(VARCHAR(191), autoincrement=False)
    billing_city = Column(VARCHAR(191), autoincrement=False)
    billing_state = Column(VARCHAR(191), autoincrement=False)
    billing_zip = Column(VARCHAR(25), autoincrement=False)
    billing_country = Column(VARCHAR(2), autoincrement=False)
    vat_id = Column(VARCHAR(50), autoincrement=False)
    extra_billing_information = Column(TEXT, autoincrement=False)
    trial_ends_at = Column(TIMESTAMP, autoincrement=False)
    last_read_announcements_at = Column(TIMESTAMP, autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    progress = Column(VARCHAR(191), autoincrement=False)
    api_secret = Column(TEXT, autoincrement=False)
    preferred_timezone = Column(VARCHAR(191), autoincrement=False)
    session_id = Column(TEXT, autoincrement=False)
    preferences = Column(TEXT, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, BIT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class MlModelsGroups(PrimaryBase):
    __tablename__ = 'ml_models_groups'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    team_id = Column(INTEGER, autoincrement=False)
    user_id = Column(INTEGER, autoincrement=False)
    name = Column(TEXT, nullable=False, autoincrement=False)
    description = Column(TEXT, autoincrement=False)
    model_type = Column(TEXT, nullable=False, autoincrement=False)
    model_prediction = Column(TEXT, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    is_generic = Column(BIT, nullable=False, autoincrement=False)
    model_network = Column(TEXT, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Invoices(PrimaryBase):
    __tablename__ = 'invoices'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    user_id = Column(INTEGER, autoincrement=False)
    team_id = Column(INTEGER, autoincrement=False)
    provider_id = Column(VARCHAR(191), nullable=False, autoincrement=False)
    total = Column(NUMERIC(8, 2), autoincrement=False)
    tax = Column(NUMERIC(8, 2), autoincrement=False)
    card_country = Column(VARCHAR(191), autoincrement=False)
    billing_state = Column(VARCHAR(191), autoincrement=False)
    billing_zip = Column(VARCHAR(191), autoincrement=False)
    billing_country = Column(VARCHAR(191), autoincrement=False)
    vat_id = Column(VARCHAR(50), autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkRptNodeDwSummaries(PrimaryBase):
    __tablename__ = 'spark_rpt_node_dw_summaries'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    order = Column(INTEGER, primary_key=True, autoincrement=False)
    node = Column(TEXT, primary_key=True, autoincrement=False)
    type = Column(TEXT, nullable=False, autoincrement=False)
    min_demand = Column(NUMERIC, autoincrement=False)
    max_demand = Column(NUMERIC, autoincrement=False)
    min_head = Column(NUMERIC, autoincrement=False)
    max_head = Column(NUMERIC, autoincrement=False)
    min_pressure = Column(NUMERIC, autoincrement=False)
    max_pressure = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    avg_demand = Column(NUMERIC, autoincrement=False)
    avg_head = Column(NUMERIC, autoincrement=False)
    avg_pressure = Column(NUMERIC, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class TeamApiKeys(PrimaryBase):
    __tablename__ = 'team_api_keys'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    team_id = Column(INTEGER, nullable=False, autoincrement=False)
    name = Column(TEXT, autoincrement=False)
    value = Column(TEXT, nullable=False, autoincrement=False)
    created_at = Column(TIMESTAMP, nullable=False, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpAdjust(PrimaryBase):
    __tablename__ = 'inp_adjust'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    parameter = Column(VARCHAR(50), nullable=False, autoincrement=False)
    subcatchment = Column(VARCHAR(50), autoincrement=False)
    m1 = Column(DOUBLE_PRECISION, autoincrement=False)
    m2 = Column(DOUBLE_PRECISION, autoincrement=False)
    m3 = Column(DOUBLE_PRECISION, autoincrement=False)
    m4 = Column(DOUBLE_PRECISION, autoincrement=False)
    m5 = Column(DOUBLE_PRECISION, autoincrement=False)
    m6 = Column(DOUBLE_PRECISION, autoincrement=False)
    m7 = Column(DOUBLE_PRECISION, autoincrement=False)
    m8 = Column(DOUBLE_PRECISION, autoincrement=False)
    m9 = Column(DOUBLE_PRECISION, autoincrement=False)
    m10 = Column(DOUBLE_PRECISION, autoincrement=False)
    m11 = Column(DOUBLE_PRECISION, autoincrement=False)
    m12 = Column(DOUBLE_PRECISION, autoincrement=False)
    flag = Column(INTEGER, autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpWeir(PrimaryBase):
    __tablename__ = 'inp_weir'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    name = Column(VARCHAR(250), autoincrement=False)
    from_node = Column(VARCHAR(250), autoincrement=False)
    to_node = Column(VARCHAR(250), autoincrement=False)
    type = Column(VARCHAR(25), autoincrement=False)
    crest_ht = Column(VARCHAR(25), autoincrement=False)
    q_coeff = Column(VARCHAR(25), autoincrement=False)
    gated = Column(VARCHAR(25), autoincrement=False)
    end_con = Column(VARCHAR(25), autoincrement=False)
    end_coeff = Column(VARCHAR(25), autoincrement=False)
    surcharge = Column(VARCHAR(25), autoincrement=False)
    road_width = Column(VARCHAR(25), autoincrement=False)
    road_surf = Column(VARCHAR(25), autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
    coeff_curve = Column(VARCHAR(50), autoincrement=False)
    mukey = Column(VARCHAR(191), autoincrement=False)
    site_id = Column(VARCHAR(191), autoincrement=False)
    is_road = Column(INTEGER, autoincrement=False)
    location = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, SMALLINT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Simulations(PrimaryBase):
    __tablename__ = 'simulations'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    user_id = Column(BIGINT, nullable=False, autoincrement=False)
    name = Column(VARCHAR(191), autoincrement=False)
    rpt_name = Column(VARCHAR(191), autoincrement=False)
    status = Column(VARCHAR(30), autoincrement=False)
    message = Column(TEXT, autoincrement=False)
    analysis_begun_on = Column(VARCHAR(30), autoincrement=False)
    analysis_ended_on = Column(VARCHAR(30), autoincrement=False)
    inp_file = Column(VARCHAR(191), autoincrement=False)
    subcatchment_file = Column(VARCHAR(191), autoincrement=False)
    node_file = Column(VARCHAR(191), autoincrement=False)
    link_file = Column(VARCHAR(191), autoincrement=False)
    text_file = Column(VARCHAR(191), autoincrement=False)
    report_file = Column(VARCHAR(191), autoincrement=False)
    out_file = Column(VARCHAR(191), autoincrement=False)
    json_file = Column(VARCHAR(191), autoincrement=False)
    created_at = Column(TIMESTAMP, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)
    reports_parser_status = Column(SMALLINT, nullable=False, autoincrement=False)
    links_parser_status = Column(SMALLINT, nullable=False, autoincrement=False)
    nodes_parser_status = Column(SMALLINT, nullable=False, autoincrement=False)
    subcatchments_parser_status = Column(SMALLINT, nullable=False, autoincrement=False)
    nodes = Column(INTEGER, nullable=False, autoincrement=False)
    links = Column(INTEGER, nullable=False, autoincrement=False)
    subcatchments = Column(INTEGER, nullable=False, autoincrement=False)
    nodes_inserted = Column(INTEGER, nullable=False, autoincrement=False)
    links_inserted = Column(INTEGER, nullable=False, autoincrement=False)
    subcatchments_inserted = Column(INTEGER, nullable=False, autoincrement=False)
    use_real_time_data = Column(VARCHAR(191), autoincrement=False)
    option_start_date_time = Column(TIMESTAMP, autoincrement=False)
    option_end_date_time = Column(TIMESTAMP, autoincrement=False)
    parsed_node_file = Column(VARCHAR(191), autoincrement=False)
    parsed_link_file = Column(VARCHAR(191), autoincrement=False)
    parsed_subcatchment_file = Column(VARCHAR(191), autoincrement=False)
    is_auto = Column(SMALLINT, autoincrement=False)
    node_geojson = Column(VARCHAR(191), autoincrement=False)
    link_geojson = Column(VARCHAR(191), autoincrement=False)
    subcatchment_geojson = Column(VARCHAR(191), autoincrement=False)
    group_name = Column(VARCHAR(191), autoincrement=False)
    forecast = Column(VARCHAR(191), autoincrement=False)
    hindcast = Column(VARCHAR(191), autoincrement=False)
    is_backtest = Column(INTEGER, autoincrement=False)
    floodplain_boundary_output = Column(VARCHAR(191), autoincrement=False)
    depth_raster_output = Column(VARCHAR(191), autoincrement=False)
    water_surface_elevation_raster_output = Column(VARCHAR(191), autoincrement=False)
    velocity_raster_output = Column(VARCHAR(191), autoincrement=False)
    flood_severity_raster_output = Column(VARCHAR(191), autoincrement=False)
    wms_url_fbo = Column(TEXT, autoincrement=False)
    wfs_url_fbo = Column(TEXT, autoincrement=False)
    wms_url_dro = Column(TEXT, autoincrement=False)
    wfs_url_dro = Column(TEXT, autoincrement=False)
    wms_url_wser = Column(TEXT, autoincrement=False)
    wfs_url_wser = Column(TEXT, autoincrement=False)
    wms_url_vro = Column(TEXT, autoincrement=False)
    wfs_url_vro = Column(TEXT, autoincrement=False)
    wms_url_fsro = Column(TEXT, autoincrement=False)
    wfs_url_fsro = Column(TEXT, autoincrement=False)
    vro_legend_url = Column(TEXT, autoincrement=False)
    dro_legend_url = Column(TEXT, autoincrement=False)
    fsro_legend_url = Column(TEXT, autoincrement=False)
    wser_legend_url = Column(TEXT, autoincrement=False)
    lof_nodes_completed = Column(INTEGER, autoincrement=False)
    lof_links_completed = Column(INTEGER, autoincrement=False)
    flooded_structures_path = Column(TEXT, autoincrement=False)
    flooded_roads_path = Column(TEXT, autoincrement=False)
    parsing_begun_on = Column(TIMESTAMP, autoincrement=False)
    parsing_ended_on = Column(TIMESTAMP, autoincrement=False)
    risk_map_status = Column(INTEGER, autoincrement=False)
    floodplain_status = Column(INTEGER, autoincrement=False)
    geoserver_status = Column(INTEGER, autoincrement=False)
    floodplain_intersection_status = Column(INTEGER, autoincrement=False)
    rainfall_event_id = Column(INTEGER, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class MyLayers(PrimaryBase):
    __tablename__ = 'my_layers'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    name = Column(VARCHAR(191), nullable=False, autoincrement=False)
    type = Column(VARCHAR(191), nullable=False, autoincrement=False)
    columns = Column(TEXT, autoincrement=False)
    geometry_type = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class MaterialServiceLife(PrimaryBase):
    __tablename__ = 'material_service_life'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    material = Column(VARCHAR, autoincrement=False)
    service_life_years = Column(INTEGER, autoincrement=False)
    project_type = Column(VARCHAR, autoincrement=False)
    structure_type = Column(VARCHAR, autoincrement=False)
    structure_details = Column(VARCHAR, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, SMALLINT
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Jobs(PrimaryBase):
    __tablename__ = 'jobs'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    queue = Column(VARCHAR(191), nullable=False, autoincrement=False)
    payload = Column(TEXT, nullable=False, autoincrement=False)
    attempts = Column(SMALLINT, nullable=False, autoincrement=False)
    reserved_at = Column(INTEGER, autoincrement=False)
    available_at = Column(INTEGER, nullable=False, autoincrement=False)
    created_at = Column(INTEGER, nullable=False, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpGroundwater(PrimaryBase):
    __tablename__ = 'inp_groundwater'
    __table_args__ = {'schema': 'public'}
    
    id = Column(INTEGER, primary_key=True, autoincrement=True)
    project_id = Column(INTEGER, nullable=False, autoincrement=False)
    subcatchment = Column(VARCHAR(250), autoincrement=False)
    aquifer = Column(VARCHAR(250), autoincrement=False)
    node = Column(VARCHAR(250), autoincrement=False)
    esurf = Column(VARCHAR(25), autoincrement=False)
    a1 = Column(VARCHAR(25), autoincrement=False)
    b1 = Column(VARCHAR(25), autoincrement=False)
    a2 = Column(VARCHAR(25), autoincrement=False)
    b2 = Column(VARCHAR(25), autoincrement=False)
    a3 = Column(VARCHAR(25), autoincrement=False)
    dsw = Column(VARCHAR(25), autoincrement=False)
    egwt = Column(VARCHAR(25), autoincrement=False)
    ebot = Column(VARCHAR(25), autoincrement=False)
    wgr = Column(VARCHAR(25), autoincrement=False)
    umc = Column(VARCHAR(25), autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class Testingspatial(PrimaryBase):
    __tablename__ = 'testingspatial'
    __table_args__ = {'schema': 'public'}
    
    column_not_exist_in_db = Column(INTEGER, primary_key=True) # Needed to circumvent primary key requirement in sqlalchemy
    id = Column(INTEGER, nullable=False, autoincrement=True)
    name = Column(VARCHAR, autoincrement=False)
    geom = Column(TEXT, autoincrement=False)
    geom2 = Column(TEXT, autoincrement=False)
    geom3 = Column(TEXT, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpOutlet(PrimaryBase):
    __tablename__ = 'inp_outlet'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    name = Column(VARCHAR(250), autoincrement=False)
    node1 = Column(VARCHAR(250), autoincrement=False)
    node2 = Column(VARCHAR(250), autoincrement=False)
    offset = Column(DOUBLE_PRECISION, autoincrement=False)
    type = Column(VARCHAR(50), autoincrement=False)
    qcurve = Column(VARCHAR(50), autoincrement=False)
    coeff1 = Column(DOUBLE_PRECISION, autoincrement=False)
    coeff2 = Column(DOUBLE_PRECISION, autoincrement=False)
    gated = Column(VARCHAR(10), autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
    mukey = Column(VARCHAR(191), autoincrement=False)
    site_id = Column(VARCHAR(191), autoincrement=False)
    is_road = Column(INTEGER, autoincrement=False)
    location = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME, JSON
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class NoaaFrequencyTables(PrimaryBase):
    __tablename__ = 'noaa_frequency_tables'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    volume = Column(INTEGER, nullable=False, autoincrement=False)
    version = Column(INTEGER, nullable=False, autoincrement=False)
    time_series_type = Column(VARCHAR(191), nullable=False, autoincrement=False)
    lat = Column(VARCHAR(191), nullable=False, autoincrement=False)
    long = Column(VARCHAR(191), nullable=False, autoincrement=False)
    upper_table = Column(JSON, autoincrement=False)
    lower_table = Column(JSON, autoincrement=False)
    mean_table = Column(JSON, autoincrement=False)
    upper_filepath = Column(VARCHAR(191), autoincrement=False)
    lower_filepath = Column(VARCHAR(191), autoincrement=False)
    mean_filepath = Column(VARCHAR(191), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpHydrographValues(PrimaryBase):
    __tablename__ = 'inp_hydrograph_values'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    inp_hydrograph_id = Column(BIGINT, nullable=False, autoincrement=False)
    rain_gage_month = Column(VARCHAR(20), nullable=False, autoincrement=False)
    response = Column(VARCHAR(20), nullable=False, autoincrement=False)
    r = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    t = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    k = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    dmax = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    drecov = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)
    dinit = Column(DOUBLE_PRECISION, nullable=False, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SpatialRefSys(PrimaryBase):
    __tablename__ = 'spatial_ref_sys'
    __table_args__ = {'schema': 'public'}
    
    srid = Column(INTEGER, primary_key=True, autoincrement=False)
    auth_name = Column(VARCHAR(256), autoincrement=False)
    auth_srid = Column(INTEGER, autoincrement=False)
    srtext = Column(VARCHAR(2048), autoincrement=False)
    proj4text = Column(VARCHAR(2048), autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class SparkReportNodeLof(PrimaryBase):
    __tablename__ = 'spark_report_node_lof'
    __table_args__ = {'schema': 'predictions'}
    
    project_id = Column(INTEGER, primary_key=True, autoincrement=False)
    simulation_id = Column(INTEGER, primary_key=True, autoincrement=False)
    name = Column(TEXT, primary_key=True, autoincrement=False)
    flow_area = Column(NUMERIC, autoincrement=False)
    ins_date = Column(DATE, autoincrement=False)
    pred_material = Column(BOOLEAN, autoincrement=False)
    pred_dim1 = Column(BOOLEAN, autoincrement=False)
    pred_dim2 = Column(BOOLEAN, autoincrement=False)
    pred_rimelev = Column(BOOLEAN, autoincrement=False)
    pred_invelev = Column(BOOLEAN, autoincrement=False)
    material = Column(TEXT, autoincrement=False)
    dim1 = Column(NUMERIC, autoincrement=False)
    dim2 = Column(NUMERIC, autoincrement=False)
    rim_ele = Column(NUMERIC, autoincrement=False)
    inv_ele = Column(NUMERIC, autoincrement=False)
    lof = Column(NUMERIC, autoincrement=False)
    created_at = Column(TIMESTAMP, primary_key=True, autoincrement=False)
    updated_at = Column(TIMESTAMP, autoincrement=False)



from sqlalchemy import Column, Sequence
from sqlalchemy.dialects.postgresql import DOUBLE_PRECISION, UUID, TIMESTAMP, TIME
from sqlalchemy.types import VARCHAR, BIGINT, DATE, INTEGER, NUMERIC, BOOLEAN, TEXT
from base import PrimaryBase

class InpLidUsage(PrimaryBase):
    __tablename__ = 'inp_lid_usage'
    __table_args__ = {'schema': 'public'}
    
    id = Column(BIGINT, primary_key=True, autoincrement=True)
    project_id = Column(BIGINT, nullable=False, autoincrement=False)
    subcatchment = Column(VARCHAR(250), autoincrement=False)
    lid_process = Column(VARCHAR(50), nullable=False, autoincrement=False)
    number = Column(DOUBLE_PRECISION, autoincrement=False)
    area = Column(DOUBLE_PRECISION, autoincrement=False)
    width = Column(DOUBLE_PRECISION, autoincrement=False)
    init_satur = Column(DOUBLE_PRECISION, autoincrement=False)
    from_imp = Column(DOUBLE_PRECISION, autoincrement=False)
    to_perv = Column(INTEGER, autoincrement=False)
    report_file = Column(VARCHAR(191), autoincrement=False)
    drain_to = Column(VARCHAR(191), autoincrement=False)
    from_perv = Column(VARCHAR(191), autoincrement=False)
    description = Column(VARCHAR(1024), autoincrement=False)
